==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/ES/DescribeElasticsearchDomainConfig.pm <==

package Paws::ES::DescribeElasticsearchDomainConfig;
  use Moose;
  has DomainName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'DomainName' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeElasticsearchDomainConfig');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-01-01/es/domain/{DomainName}/config');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ES::DescribeElasticsearchDomainConfigResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeElasticsearchDomainConfigResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ES::DescribeElasticsearchDomainConfig - Arguments for method DescribeElasticsearchDomainConfig on Paws::ES

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeElasticsearchDomainConfig on the 
Amazon Elasticsearch Service service. Use the attributes of this class
as arguments to method DescribeElasticsearchDomainConfig.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeElasticsearchDomainConfig.

As an example:

  $service_obj->DescribeElasticsearchDomainConfig(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> DomainName => Str

  

The Elasticsearch domain that you want to get information about.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeElasticsearchDomainConfig in L<Paws::ES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.18.tar.gz: Paws-0.18/lib/Paws/ES/DescribeElasticsearchDomainConfig.pm <==

package Paws::ES::DescribeElasticsearchDomainConfig;
  use Moose;
  has DomainName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'DomainName' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeElasticsearchDomainConfig');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-01-01/es/domain/{DomainName}/config');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ES::DescribeElasticsearchDomainConfigResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeElasticsearchDomainConfigResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ES::DescribeElasticsearchDomainConfig - Arguments for method DescribeElasticsearchDomainConfig on Paws::ES

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeElasticsearchDomainConfig on the 
Amazon Elasticsearch Service service. Use the attributes of this class
as arguments to method DescribeElasticsearchDomainConfig.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeElasticsearchDomainConfig.

As an example:

  $service_obj->DescribeElasticsearchDomainConfig(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> DomainName => Str

  The Elasticsearch domain that you want to get information about.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeElasticsearchDomainConfig in L<Paws::ES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
